
/* 
 * Copyright (c) 1993-2003,2012 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/

#ifndef force_MSG_LIB_H
#define force_MSG_LIB_H

#include "portLib.h"
#include "csLib.h"
#include "posterLib.h"
 
#include "forceType.h"

#define TIME_WAIT_REPLY           /*2000*/ 0
 



/*----------- Tailles des messages et boites aux lettres  ----------*/

/* Taille du buffer utilise dans la bal pour un mesage de taille size
 * (cf servMbox pour UNIX et h2rgnLib pour VXWORKS )
 */


#define BUF_SIZE(size) \
   (size + 4 - (size & 3) + sizeof(LETTER_HDR) + 8)

/**
 ** Boite aux lettres reception requetes 
 **/
#define  FORCE_MBOX_NAME                  genomInstanceName("force")

#define  FORCE_MAX_RQST_SIZE              56

#define  FORCE_MBOX_RQST_SIZE       \
 (BUF_SIZE(FORCE_MAX_RQST_SIZE) * SERV_NMAX_RQST_ID)

/** 
 ** Taille max repliques (serveur)
 **/
#define  FORCE_MAX_INTERMED_REPLY_SIZE   (sizeof(int))

#define  FORCE_MAX_REPLY_SIZE             48

/** 
 ** Taille bal clients pour reception repliques 
 **/
#define  FORCE_CLIENT_MBOX_REPLY_SIZE   \
((BUF_SIZE(FORCE_MAX_REPLY_SIZE) \
   + BUF_SIZE(FORCE_MAX_INTERMED_REPLY_SIZE)) \
 * CLIENT_NMAX_RQST_ID)

/*-------------------------- Liste des requetes  -------------------------*/

#define FORCE_INIT_RQST 0
#define FORCE_INITNUMBERFFT_RQST 1
#define FORCE_INITFFTDIRECTION_RQST 2
#define FORCE_FILTERSET_RQST 3
#define FORCE_OFFSETRESET_RQST 4
#define FORCE_DETECT_RQST 5
#define FORCE_DETECTSTOP_RQST 6
#define FORCE_DETECTSET_NB_VAL_FFT_RQST 7
#define FORCE_DETECTSETTHRESHOLD_RQST 8
#define FORCE_MONITORFORCES_RQST 9
#define FORCE_MONITORFORCESSTOP_RQST 10
#define FORCE_SAVEFILEFFT_RQST 11
#define FORCE_RECORDFORCES_RQST 12
#define FORCE_ABORT_RQST 13


/*---------------- PROTOTYPES DES FONCTIONS EXTERNES ------------------*/

#ifdef __cplusplus
extern "C" {
#endif

STATUS forceClientInit (CLIENT_ID *pClientId);

STATUS forceClientEnd (CLIENT_ID clientId);

int forceAbortRqstSend (CLIENT_ID clientId, 
			   int *pRqstId,
			   int *activity,
			   int replyTimeOut);

int forceAbortReplyRcv (CLIENT_ID clientId, 
			   int rqstId, 
			   int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			   int *bilan);

int forceAbortRqstAndRcv (CLIENT_ID clientId, 
			     int *activity,
			     int *bilan);




extern STATUS forceInitRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int forceInitReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int forceInitRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int forceInitRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS forceInitNumberFFTRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 int *(in_numberFFT),
					 int replyTimeOut);

int forceInitNumberFFTReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int forceInitNumberFFTRqstAndRcv (CLIENT_ID clientId, 
				 int *(in_numberFFT), 
				 
				 int *bilan);




extern STATUS forceInitFftDirectionRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 Gb_force *(in_fftDirection),
					 int replyTimeOut);

int forceInitFftDirectionReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       Gb_force *(out_fftDirection),
			       int *bilan);

int forceInitFftDirectionRqstAndRcv (CLIENT_ID clientId, 
				 Gb_force *(in_fftDirection), 
				 Gb_force *(out_fftDirection),
				 int *bilan);




extern STATUS forceFilterSetRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 int *(in_filter),
					 int replyTimeOut);

int forceFilterSetReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       int *(out_filter),
			       int *bilan);

int forceFilterSetRqstAndRcv (CLIENT_ID clientId, 
				 int *(in_filter), 
				 int *(out_filter),
				 int *bilan);




extern STATUS forceOffsetResetRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int forceOffsetResetReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int forceOffsetResetRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);




extern STATUS forceDetectRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int forceDetectReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int forceDetectRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int forceDetectRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS forceDetectStopRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int forceDetectStopReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int forceDetectStopRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);




extern STATUS forceDetectSet_nb_val_fftRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 int *(in_nb_val_fft),
					 int replyTimeOut);

int forceDetectSet_nb_val_fftReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       int *(out_nb_val_fft),
			       int *bilan);

int forceDetectSet_nb_val_fftRqstAndRcv (CLIENT_ID clientId, 
				 int *(in_nb_val_fft), 
				 int *(out_nb_val_fft),
				 int *bilan);




extern STATUS forceDetectSetThresholdRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 double *(in_threshold),
					 int replyTimeOut);

int forceDetectSetThresholdReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       double *(out_threshold),
			       int *bilan);

int forceDetectSetThresholdRqstAndRcv (CLIENT_ID clientId, 
				 double *(in_threshold), 
				 double *(out_threshold),
				 int *bilan);




extern STATUS forceMonitorForcesRqstSend (CLIENT_ID clientId, int *pRqstId,
					 FORCE_MONITOR_DATA_STR *(in_eq),
					 int replyTimeOut);

extern int forceMonitorForcesReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int forceMonitorForcesRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					FORCE_MONITOR_DATA_STR *(in_eq), 
					
					int *activity, int *bilan);

extern int forceMonitorForcesRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					FORCE_MONITOR_DATA_STR *(in_eq), 
					
					int *activity,
					int *bilan);




extern STATUS forceMonitorForcesStopRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int forceMonitorForcesStopReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int forceMonitorForcesStopRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);




extern STATUS forceSaveFileFFTRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int forceSaveFileFFTReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int forceSaveFileFFTRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int forceSaveFileFFTRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS forceRecordForcesRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int forceRecordForcesReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int forceRecordForcesRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);


#ifdef __cplusplus
}
#endif
#endif /* force_MSG_LIB_H */

